@@ -4,16 +4,14 @@ package # hide from PAUSE
 use strict;
 use warnings;
 
-use DBICTest::Util qw( local_umask await_flock dbg DEBUG_TEST_CONCURRENCY_LOCKS );
+use DBICTest::Util 'local_umask';
 use DBICTest::Schema;
 use DBICTest::Util::LeakTracer qw/populate_weakregistry assert_empty_weakregistry/;
-use DBIx::Class::_Util 'detected_reinvoked_destructor';
 use Carp;
 use Path::Class::File ();
 use File::Spec;
 use Fcntl qw/:DEFAULT :flock/;
 use Config;
-use Scope::Guard ();
 
 =head1 NAME
 
@@ -91,14 +89,7 @@ sub import {
 
     for my $exp (@_) {
         if ($exp eq ':GlobalLock') {
-            DEBUG_TEST_CONCURRENCY_LOCKS > 1
-              and dbg "Waiting for EXCLUSIVE global lock...";
-
-            await_flock ($global_lock_fh, LOCK_EX) or die "Unable to lock $lockpath: $!";
-
-            DEBUG_TEST_CONCURRENCY_LOCKS > 1
-              and dbg "Got EXCLUSIVE global lock";
-
+            flock ($global_lock_fh, LOCK_EX) or die "Unable to lock $lockpath: $!";
             $global_exclusive_lock = 1;
         }
         elsif ($exp eq ':DiffSQL') {
@@ -115,22 +106,13 @@ sub import {
     }
 
     unless ($global_exclusive_lock) {
-        DEBUG_TEST_CONCURRENCY_LOCKS > 1
-          and dbg "Waiting for SHARED global lock...";
-
-        await_flock ($global_lock_fh, LOCK_SH) or die "Unable to lock $lockpath: $!";
-
-        DEBUG_TEST_CONCURRENCY_LOCKS > 1
-          and dbg "Got SHARED global lock";
+        flock ($global_lock_fh, LOCK_SH) or die "Unable to lock $lockpath: $!";
     }
 }
 
 END {
-    # referencing here delays destruction even more
     if ($global_lock_fh) {
-      DEBUG_TEST_CONCURRENCY_LOCKS > 1
-        and dbg "Release @{[ $global_exclusive_lock ? 'EXCLUSIVE' : 'SHARED' ]} global lock (END)";
-      1;
+        # delay destruction even more
     }
 }
 
@@ -160,7 +142,6 @@ END {
 
 $SIG{INT} = sub { _cleanup_dbfile(); exit 1 };
 
-my $need_global_cleanup;
 sub _cleanup_dbfile {
     # cleanup if this is us
     if (
@@ -170,10 +151,6 @@ sub _cleanup_dbfile {
         or
       $ENV{DBICTEST_LOCK_HOLDER} == $$
     ) {
-        if ($need_global_cleanup and my $dbh = DBICTest->schema->storage->_dbh) {
-          $dbh->disconnect;
-        }
-
         my $db_file = _sqlite_dbfilename();
         unlink $_ for ($db_file, "${db_file}-journal");
     }
@@ -240,7 +217,7 @@ sub _database {
           $dbh->{Callbacks} = {
             connect => sub { $guard_cb->('connect') },
             disconnect => sub { $guard_cb->('disconnect') },
-            DESTROY => sub { &detected_reinvoked_destructor; $guard_cb->('DESTROY') },
+            DESTROY => sub { $guard_cb->('DESTROY') },
           };
         }
       },
@@ -338,7 +315,6 @@ sub init_schema {
     my $schema;
 
     if ($args{compose_connection}) {
-      $need_global_cleanup = 1;
       $schema = DBICTest::Schema->compose_connection(
                   'DBICTest', $self->_database(%args)
                 );
@@ -367,7 +343,10 @@ sub init_schema {
 }
 
 END {
+  # Make sure we run after any cleanup in other END blocks
+  push @{ B::end_av()->object_2svref }, sub {
     assert_empty_weakregistry($weak_registry, 'quiet');
+  };
 }
 
 =head2 deploy_schema
@@ -387,11 +366,8 @@ sub deploy_schema {
     my $schema = shift;
     my $args = shift || {};
 
-    my $guard;
-    if ( ($ENV{TRAVIS}||'') eq 'true' and my $old_dbg = $schema->storage->debug ) {
-      $guard = Scope::Guard->new(sub { $schema->storage->debug($old_dbg) });
-      $schema->storage->debug(0);
-    }
+    local $schema->storage->{debug}
+      if ($ENV{TRAVIS}||'') eq 'true';
 
     if ($ENV{"DBICTEST_SQLT_DEPLOY"}) {
         $schema->deploy($args);
@@ -421,11 +397,8 @@ sub populate_schema {
     my $self = shift;
     my $schema = shift;
 
-    my $guard;
-    if ( ($ENV{TRAVIS}||'') eq 'true' and my $old_dbg = $schema->storage->debug ) {
-      $guard = Scope::Guard->new(sub { $schema->storage->debug($old_dbg) });
-      $schema->storage->debug(0);
-    }
+    local $schema->storage->{debug}
+      if ($ENV{TRAVIS}||'') eq 'true';
 
     $schema->populate('Genre', [
       [qw/genreid name/],
